==> 0.5.6.tar.gz: lib/widget/vgk-damage-widget/vgk-best-attachment-set-list.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkBestAttachmentSetList extends StatefulWidget {
  const VgkBestAttachmentSetList(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data,
      this.width,
      this.height})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final double width;
  final double height;
  final List<VgkAttachementModel> data;
  @override
  _VgkBestAttachmentSetListState createState() =>
      _VgkBestAttachmentSetListState();
}

class _VgkBestAttachmentSetListState extends State<VgkBestAttachmentSetList>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: Container(
              height: widget.height,
              width: double.infinity,
              child: ListView.builder(
                padding: const EdgeInsets.only(
                    top: 0, bottom: 0, right: 16, left: 16),
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return BestAttachmentSet(
                    data: widget.data[index],
                    animation: animation,
                    animationController: animationController,
                    width: widget.width,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

class BestAttachmentSet extends StatelessWidget {
  const BestAttachmentSet(
      {Key key,
      this.data,
      this.animationController,
      this.animation,
      this.width})
      : super(key: key);

  final double width;
  final VgkAttachementModel data;
  final AnimationController animationController;
  final Animation<dynamic> animation;
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: SizedBox(
              width: width,
              child: Stack(
                children: <Widget>[
                  Padding(
                    padding: EdgeInsets.only(top: 16, right: 8, bottom: 16),
                    child: Container(
                      width: width,
                      decoration: VgkProGamingTheme.cardDecorationWithPopUp,
                      child: Padding(
                        padding: const EdgeInsets.only(
                            top: 54, left: 16, right: 16, bottom: 8),
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              data.key.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h1White,
                            ),
                            SizedBox(
                              height: 8,
                            ),
                            Text(
                              data.value.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h3White,
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Positioned(
                    top: 0,
                    left: 0,
                    child: Container(
                      width: 84,
                      height: 84,
                      decoration: BoxDecoration(
                        color: VgkProGamingTheme.nearlyWhite.withOpacity(0.2),
                        shape: BoxShape.circle,
                      ),
                    ),
                  ),
                  Positioned(
                    top: 20,
                    left: 20,
                    child: SizedBox(
                      width: 50,
                      height: 50,
                      child: CachedNetworkImage(
                        imageUrl: data.src,
                        progressIndicatorBuilder:
                            (context, url, downloadProgress) =>
                                CircularProgressIndicator(
                                    value: downloadProgress.progress),
                        errorWidget: (context, url, error) => Icon(Icons.error),
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}

==> 0.9.3.tar.gz: lib/widget/vgk-damage-widget/vgk-best-attachment-set-list.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkBestAttachmentSetList extends StatefulWidget {
  const VgkBestAttachmentSetList(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data,
      this.width,
      this.height})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final double width;
  final double height;
  final List<VgkAttachementModel> data;
  @override
  _VgkBestAttachmentSetListState createState() =>
      _VgkBestAttachmentSetListState();
}

class _VgkBestAttachmentSetListState extends State<VgkBestAttachmentSetList>
    with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform: VgkProGamingTheme.transform(widget.mainScreenAnimation),
            child: Container(
              height: widget.height,
              width: double.infinity,
              child: ListView.builder(
                padding: const EdgeInsets.only(
                    top: 0, bottom: 0, right: 16, left: 16),
                itemCount: widget.data.length,
                scrollDirection: Axis.horizontal,
                itemBuilder: (BuildContext context, int index) {
                  final Animation<double> animation =
                      VgkProGamingTheme.animationOption(animationController);
                  animationController.forward();
                  return BestAttachmentSet(
                    data: widget.data[index],
                    animation: animation,
                    animationController: animationController,
                    width: widget.width,
                  );
                },
              ),
            ),
          ),
        );
      },
    );
  }
}

class BestAttachmentSet extends StatelessWidget {
  const BestAttachmentSet(
      {Key key,
      this.data,
      this.animationController,
      this.animation,
      this.width,
      this.primaryColor})
      : super(key: key);

  final double width;
  final VgkAttachementModel data;
  final AnimationController animationController;
  final Animation<dynamic> animation;
  final String primaryColor;
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: SizedBox(
              width: width,
              child: Stack(
                children: <Widget>[
                  Padding(
                    padding: EdgeInsets.only(top: 16, right: 8, bottom: 16),
                    child: Container(
                      width: width,
                      decoration: VgkProGamingTheme.cardDecorationWithPopUp(
                          primaryColor),
                      child: Padding(
                        padding: const EdgeInsets.only(
                            top: 54, left: 16, right: 16, bottom: 8),
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              data.key.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h1White,
                            ),
                            SizedBox(
                              height: 8,
                            ),
                            Text(
                              data.value.toLowerCase(),
                              textAlign: TextAlign.center,
                              style: VgkProGamingTheme.h3White,
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Positioned(
                    top: 0,
                    left: 0,
                    child: Container(
                      width: 84,
                      height: 84,
                      decoration: BoxDecoration(
                        color: VgkProGamingTheme.nearlyWhite.withOpacity(0.2),
                        shape: BoxShape.circle,
                      ),
                    ),
                  ),
                  Positioned(
                    top: 20,
                    left: 20,
                    child: SizedBox(
                      width: 50,
                      height: 50,
                      child: CachedNetworkImage(
                        imageUrl: data.src,
                        progressIndicatorBuilder:
                            (context, url, downloadProgress) =>
                                CircularProgressIndicator(
                                    value: downloadProgress.progress),
                        errorWidget: (context, url, error) => Icon(Icons.error),
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
